/**
 * Copyright 2024 cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

import { ApiSchoolEntryCountryCode } from "@eshg/citizen-portal-api/schoolEntry";
import { EnumMap } from "@eshg/lib-portal/types/helpers";

const CountryCodesWithoutGeneralGroups = Object.values(
  ApiSchoolEntryCountryCode,
).filter(
  (code) =>
    code !== ApiSchoolEntryCountryCode.G1 &&
    code !== ApiSchoolEntryCountryCode.G2 &&
    code !== ApiSchoolEntryCountryCode.G3 &&
    code !== ApiSchoolEntryCountryCode.G4 &&
    code !== ApiSchoolEntryCountryCode.G5 &&
    code !== ApiSchoolEntryCountryCode.G6 &&
    code !== ApiSchoolEntryCountryCode.G7 &&
    code !== ApiSchoolEntryCountryCode.G8 &&
    code !== ApiSchoolEntryCountryCode.G9,
);

type CountryCodesWithoutGeneralGroups =
  (typeof CountryCodesWithoutGeneralGroups)[number];

export const COUNTRY_CODE_VALUES: EnumMap<CountryCodesWithoutGeneralGroups> = {
  [ApiSchoolEntryCountryCode.Deu]: "Deutschland",
  [ApiSchoolEntryCountryCode.Afg]: "Afghanistan",
  [ApiSchoolEntryCountryCode.Egy]: "Ägypten",
  [ApiSchoolEntryCountryCode.Alb]: "Albanien",
  [ApiSchoolEntryCountryCode.Alg]: "Algerien",
  [ApiSchoolEntryCountryCode.And]: "Andorra",
  [ApiSchoolEntryCountryCode.Ang]: "Angola",
  [ApiSchoolEntryCountryCode.Aub]: "Antigua und Barbuda",
  [ApiSchoolEntryCountryCode.Gnq]: "Äquatorialguinea",
  [ApiSchoolEntryCountryCode.Ara]: "Arabien",
  [ApiSchoolEntryCountryCode.Arg]: "Argentinien",
  [ApiSchoolEntryCountryCode.Arm]: "Armenien",
  [ApiSchoolEntryCountryCode.Ase]: "Aserbaidschan",
  [ApiSchoolEntryCountryCode.Asn]: "Asien",
  [ApiSchoolEntryCountryCode.Eth]: "Äthiopien",
  [ApiSchoolEntryCountryCode.Aus]: "Australien",
  [ApiSchoolEntryCountryCode.Bam]: "Bahamas",
  [ApiSchoolEntryCountryCode.Bah]: "Bahrain",
  [ApiSchoolEntryCountryCode.Bal]: "Baltikum",
  [ApiSchoolEntryCountryCode.Bad]: "Bangladesch",
  [ApiSchoolEntryCountryCode.Bar]: "Barbados",
  [ApiSchoolEntryCountryCode.Bel]: "Belgien",
  [ApiSchoolEntryCountryCode.Bez]: "Belize",
  [ApiSchoolEntryCountryCode.Ben]: "Benin",
  [ApiSchoolEntryCountryCode.Bhu]: "Bhutan",
  [ApiSchoolEntryCountryCode.Bol]: "Bolivien",
  [ApiSchoolEntryCountryCode.Bos]: "Bosnien-Herzegowina",
  [ApiSchoolEntryCountryCode.Bot]: "Botswana",
  [ApiSchoolEntryCountryCode.Bra]: "Brasilien",
  [ApiSchoolEntryCountryCode.Bru]: "Brunei",
  [ApiSchoolEntryCountryCode.Bul]: "Bulgarien",
  [ApiSchoolEntryCountryCode.Buf]: "Burkina Faso",
  [ApiSchoolEntryCountryCode.Bur]: "Burundi",
  [ApiSchoolEntryCountryCode.Chi]: "Chile",
  [ApiSchoolEntryCountryCode.Chv]: "China",
  [ApiSchoolEntryCountryCode.Coo]: "Cookinseln",
  [ApiSchoolEntryCountryCode.Cor]: "Costa Rica",
  [ApiSchoolEntryCountryCode.Civ]: "Côte d'Ivoire",
  [ApiSchoolEntryCountryCode.Dan]: "Dänemark",
  [ApiSchoolEntryCountryCode.Doa]: "Dominica",
  [ApiSchoolEntryCountryCode.Dom]: "Dominikanische Republik",
  [ApiSchoolEntryCountryCode.Dsc]: "Dschibuti",
  [ApiSchoolEntryCountryCode.Ecu]: "Ecuador",
  [ApiSchoolEntryCountryCode.Els]: "El Salvador",
  [ApiSchoolEntryCountryCode.Bri]: "England",
  [ApiSchoolEntryCountryCode.Ery]: "Eritrea",
  [ApiSchoolEntryCountryCode.Est]: "Estland",
  [ApiSchoolEntryCountryCode.Fid]: "Fidschi",
  [ApiSchoolEntryCountryCode.Fin]: "Finnland",
  [ApiSchoolEntryCountryCode.Fra]: "Frankreich",
  [ApiSchoolEntryCountryCode.Gab]: "Gabun",
  [ApiSchoolEntryCountryCode.Gam]: "Gambia",
  [ApiSchoolEntryCountryCode.Geo]: "Georgien",
  [ApiSchoolEntryCountryCode.Gha]: "Ghana",
  [ApiSchoolEntryCountryCode.Gol]: "Golfstaaten",
  [ApiSchoolEntryCountryCode.Gre]: "Grenada",
  [ApiSchoolEntryCountryCode.Gri]: "Griechenland",
  [ApiSchoolEntryCountryCode.Gua]: "Guatemala",
  [ApiSchoolEntryCountryCode.Gui]: "Guinea",
  [ApiSchoolEntryCountryCode.Gus]: "GUS-Rest",
  [ApiSchoolEntryCountryCode.Guy]: "Guyana",
  [ApiSchoolEntryCountryCode.Hai]: "Haiti",
  [ApiSchoolEntryCountryCode.Hnd]: "Honduras",
  [ApiSchoolEntryCountryCode.Ind]: "Indien",
  [ApiSchoolEntryCountryCode.Ins]: "Indonesien",
  [ApiSchoolEntryCountryCode.Irq]: "Irak",
  [ApiSchoolEntryCountryCode.Ira]: "Iran",
  [ApiSchoolEntryCountryCode.Irl]: "Irland",
  [ApiSchoolEntryCountryCode.Isl]: "Island",
  [ApiSchoolEntryCountryCode.Isr]: "Israel",
  [ApiSchoolEntryCountryCode.Ita]: "Italien",
  [ApiSchoolEntryCountryCode.Jam]: "Jamaika",
  [ApiSchoolEntryCountryCode.Jap]: "Japan",
  [ApiSchoolEntryCountryCode.Jem]: "Jemen",
  [ApiSchoolEntryCountryCode.Jor]: "Jordanien",
  [ApiSchoolEntryCountryCode.Jug]: "Jug-Rest",
  [ApiSchoolEntryCountryCode.Kam]: "Kambodscha",
  [ApiSchoolEntryCountryCode.Kan]: "Kamerun",
  [ApiSchoolEntryCountryCode.Can]: "Kanada",
  [ApiSchoolEntryCountryCode.Kap]: "Kap Verde",
  [ApiSchoolEntryCountryCode.Kas]: "Kasachstan",
  [ApiSchoolEntryCountryCode.Kat]: "Katar",
  [ApiSchoolEntryCountryCode.Ken]: "Kenia",
  [ApiSchoolEntryCountryCode.Kir]: "Kirgistan",
  [ApiSchoolEntryCountryCode.Kib]: "Kiribati",
  [ApiSchoolEntryCountryCode.Kol]: "Kolumbien",
  [ApiSchoolEntryCountryCode.Kom]: "Komoren",
  [ApiSchoolEntryCountryCode.Kon]: "Kongo",
  [ApiSchoolEntryCountryCode.Kor]: "Korea",
  [ApiSchoolEntryCountryCode.Kos]: "Kosovo",
  [ApiSchoolEntryCountryCode.Kro]: "Kroatien",
  [ApiSchoolEntryCountryCode.Kub]: "Kuba",
  [ApiSchoolEntryCountryCode.Kuw]: "Kuwait",
  [ApiSchoolEntryCountryCode.Lao]: "Laos",
  [ApiSchoolEntryCountryCode.Lso]: "Lesotho",
  [ApiSchoolEntryCountryCode.Let]: "Lettland",
  [ApiSchoolEntryCountryCode.Leb]: "Libanon",
  [ApiSchoolEntryCountryCode.Lib]: "Liberia",
  [ApiSchoolEntryCountryCode.Lyb]: "Libyen",
  [ApiSchoolEntryCountryCode.Lie]: "Liechtenstein",
  [ApiSchoolEntryCountryCode.Lit]: "Litauen",
  [ApiSchoolEntryCountryCode.Lux]: "Luxemburg",
  [ApiSchoolEntryCountryCode.Mad]: "Madagaskar",
  [ApiSchoolEntryCountryCode.Maw]: "Malawi",
  [ApiSchoolEntryCountryCode.May]: "Malaysia",
  [ApiSchoolEntryCountryCode.Mal]: "Malediven",
  [ApiSchoolEntryCountryCode.Mai]: "Mali",
  [ApiSchoolEntryCountryCode.Mlt]: "Malta",
  [ApiSchoolEntryCountryCode.Mar]: "Marokko",
  [ApiSchoolEntryCountryCode.Mhl]: "Marshallinseln",
  [ApiSchoolEntryCountryCode.Mau]: "Mauretanien",
  [ApiSchoolEntryCountryCode.Mas]: "Mauritius",
  [ApiSchoolEntryCountryCode.Maz]: "Nordmazedonien",
  [ApiSchoolEntryCountryCode.Mex]: "Mexiko",
  [ApiSchoolEntryCountryCode.Mik]: "Mikronesien",
  [ApiSchoolEntryCountryCode.Mam]: "Mittelamerika",
  [ApiSchoolEntryCountryCode.Mol]: "Moldau",
  [ApiSchoolEntryCountryCode.Mon]: "Monaco",
  [ApiSchoolEntryCountryCode.Mog]: "Mongolei",
  [ApiSchoolEntryCountryCode.Mne]: "Montenegro",
  [ApiSchoolEntryCountryCode.Mos]: "Mosambik",
  [ApiSchoolEntryCountryCode.Mya]: "Myanmar",
  [ApiSchoolEntryCountryCode.Nam]: "Namibia",
  [ApiSchoolEntryCountryCode.Chn]: "Nation China",
  [ApiSchoolEntryCountryCode.Nau]: "Nauru",
  [ApiSchoolEntryCountryCode.Nep]: "Nepal",
  [ApiSchoolEntryCountryCode.Neu]: "Neuseeland",
  [ApiSchoolEntryCountryCode.Nic]: "Nicaragua",
  [ApiSchoolEntryCountryCode.Ned]: "Niederlande",
  [ApiSchoolEntryCountryCode.Nig]: "Niger",
  [ApiSchoolEntryCountryCode.Nia]: "Nigeria",
  [ApiSchoolEntryCountryCode.Nok]: "Nordkorea",
  [ApiSchoolEntryCountryCode.Nor]: "Norwegen",
  [ApiSchoolEntryCountryCode.Oma]: "Oman",
  [ApiSchoolEntryCountryCode.Ost]: "Österreich",
  [ApiSchoolEntryCountryCode.Pak]: "Pakistan",
  [ApiSchoolEntryCountryCode.Pal]: "Palästina",
  [ApiSchoolEntryCountryCode.Pau]: "Palau",
  [ApiSchoolEntryCountryCode.Pan]: "Panama",
  [ApiSchoolEntryCountryCode.Pap]: "Papua Neuguinea",
  [ApiSchoolEntryCountryCode.Par]: "Paraguay",
  [ApiSchoolEntryCountryCode.Per]: "Peru",
  [ApiSchoolEntryCountryCode.Phi]: "Philippinen",
  [ApiSchoolEntryCountryCode.Pol]: "Polen",
  [ApiSchoolEntryCountryCode.Por]: "Portugal",
  [ApiSchoolEntryCountryCode.Rua]: "Ruanda",
  [ApiSchoolEntryCountryCode.Rum]: "Rumänien",
  [ApiSchoolEntryCountryCode.Rus]: "Russische Föderation",
  [ApiSchoolEntryCountryCode.Sal]: "Salomonen",
  [ApiSchoolEntryCountryCode.Sab]: "Sambia",
  [ApiSchoolEntryCountryCode.Saa]: "Samoa",
  [ApiSchoolEntryCountryCode.San]: "San Marino",
  [ApiSchoolEntryCountryCode.Stl]: "Santa-Lucia",
  [ApiSchoolEntryCountryCode.Stp]: "Sao Tome und Principe",
  [ApiSchoolEntryCountryCode.Sau]: "Saudi-Arabien",
  [ApiSchoolEntryCountryCode.Sco]: "Schottland",
  [ApiSchoolEntryCountryCode.Sve]: "Schweden",
  [ApiSchoolEntryCountryCode.Hel]: "Schweiz",
  [ApiSchoolEntryCountryCode.Sen]: "Senegal",
  [ApiSchoolEntryCountryCode.Ser]: "Serbien",
  [ApiSchoolEntryCountryCode.Sey]: "Seychellen",
  [ApiSchoolEntryCountryCode.Sil]: "Sierra Leone",
  [ApiSchoolEntryCountryCode.Sim]: "Simbabwe",
  [ApiSchoolEntryCountryCode.Sin]: "Singapur",
  [ApiSchoolEntryCountryCode.Skn]: "Slowakei",
  [ApiSchoolEntryCountryCode.Slo]: "Slowenien",
  [ApiSchoolEntryCountryCode.Som]: "Somalia",
  [ApiSchoolEntryCountryCode.Spa]: "Spanien",
  [ApiSchoolEntryCountryCode.Cey]: "Sri Lanka",
  [ApiSchoolEntryCountryCode.Stk]: "St. Kitts und Nevis",
  [ApiSchoolEntryCountryCode.Vct]: "St. Vincent und die Grenadinen",
  [ApiSchoolEntryCountryCode.Sar]: "Südafrika",
  [ApiSchoolEntryCountryCode.Sam]: "Südamerika",
  [ApiSchoolEntryCountryCode.Sud]: "Sudan",
  [ApiSchoolEntryCountryCode.Suk]: "Südkorea",
  [ApiSchoolEntryCountryCode.Sur]: "Suriname",
  [ApiSchoolEntryCountryCode.Swa]: "Eswatini",
  [ApiSchoolEntryCountryCode.Syr]: "Syrien",
  [ApiSchoolEntryCountryCode.Tad]: "Tadschikistan",
  [ApiSchoolEntryCountryCode.Tai]: "Taiwan",
  [ApiSchoolEntryCountryCode.Tan]: "Tansania",
  [ApiSchoolEntryCountryCode.Tha]: "Thailand",
  [ApiSchoolEntryCountryCode.Tib]: "Tibet",
  [ApiSchoolEntryCountryCode.Tim]: "Timor",
  [ApiSchoolEntryCountryCode.Tog]: "Togo",
  [ApiSchoolEntryCountryCode.Trt]: "Trinidad und Tobago",
  [ApiSchoolEntryCountryCode.Cha]: "Tschad",
  [ApiSchoolEntryCountryCode.Czn]: "Tschechische Republik",
  [ApiSchoolEntryCountryCode.Tun]: "Tunesien",
  [ApiSchoolEntryCountryCode.Tur]: "Türkei",
  [ApiSchoolEntryCountryCode.Tkm]: "Turkmenistan",
  [ApiSchoolEntryCountryCode.Tuv]: "Tuvalu",
  [ApiSchoolEntryCountryCode.Uga]: "Uganda",
  [ApiSchoolEntryCountryCode.Ukr]: "Ukraine",
  [ApiSchoolEntryCountryCode.Ung]: "Ungarn",
  [ApiSchoolEntryCountryCode.Uru]: "Uruguay",
  [ApiSchoolEntryCountryCode.Usa]: "USA",
  [ApiSchoolEntryCountryCode.Usb]: "Usbekistan",
  [ApiSchoolEntryCountryCode.Van]: "Vanuatu",
  [ApiSchoolEntryCountryCode.Vat]: "Vatikanstadt",
  [ApiSchoolEntryCountryCode.Ven]: "Venezuela",
  [ApiSchoolEntryCountryCode.Vae]: "Vereinigte Arabische Emirate",
  [ApiSchoolEntryCountryCode.Vie]: "Vietnam",
  [ApiSchoolEntryCountryCode.Wru]: "Belarus",
  [ApiSchoolEntryCountryCode.Sca]: "Zentralafrikanische Republik",
  [ApiSchoolEntryCountryCode.Zyp]: "Zypern",
  [ApiSchoolEntryCountryCode.Uuu]: "Unbekannt",
  [ApiSchoolEntryCountryCode.Son]: "sonstige Staaten",
  [ApiSchoolEntryCountryCode.Sta]: "staatenlos",
};
