/**
 * Copyright 2024 SCOOP Software GmbH, cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

import { ApiMedicalHistorySectionElement } from "@eshg/employee-portal-api/travelMedicine";
import { SetFieldValueHelper } from "@eshg/lib-portal/types/form";
import { FormLabel, styled } from "@mui/joy";

import { RadioButtonsField } from "@/lib/shared/components/formFields/RadioButtonsField";

interface MedicalHistoryRadioButtonElementProps {
  name: string;
  label: string;
  setFieldValue: SetFieldValueHelper;
  element: ApiMedicalHistorySectionElement;
  sectionIndex: number;
  elementIndex: number;
  readOnly?: boolean;
}

export function MedicalHistoryRadioButtonElement({
  name,
  label,
  element,
  setFieldValue,
  sectionIndex,
  elementIndex,
  readOnly = false,
}: Readonly<MedicalHistoryRadioButtonElementProps>) {
  const StyledLabelComponent = styled(FormLabel)(() => ({
    fontSize: 14,
  }));

  return (
    <RadioButtonsField
      name={name}
      label={<StyledLabelComponent>{label}</StyledLabelComponent>}
      options={[
        { value: "true", label: "Ja" },
        { value: "false", label: "Nein" },
      ]}
      onChange={async (event) => {
        if (event.target.value === "false" || !event.target.value) {
          if (element.elementData.subElementText) {
            await setFieldValue(
              "medicalHistoryContent.sections[" +
                sectionIndex +
                "].sectionElements[" +
                elementIndex +
                "].elementData.subElementText.answer",
              "",
            );
          }
          for (
            let i = 0;
            i < element.elementData.subElementMultiSelect.length;
            i++
          ) {
            await setFieldValue(
              "medicalHistoryContent.sections[" +
                sectionIndex +
                "].sectionElements[" +
                elementIndex +
                "].elementData.subElementMultiSelect[" +
                i +
                "].answer",
              false,
            );
          }
          await setFieldValue(
            "medicalHistoryContent.sections[" +
              sectionIndex +
              "].sectionElements[" +
              elementIndex +
              "].elementData.answer",
            false,
          );
        } else {
          await setFieldValue(
            "medicalHistoryContent.sections[" +
              sectionIndex +
              "].sectionElements[" +
              elementIndex +
              "].elementData.answer",
            true,
          );
        }
      }}
      disabled={readOnly}
    />
  );
}
